Index: /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.h
===================================================================
--- /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.h	(revision 42466)
+++ /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.h	(revision 42467)
@@ -2,5 +2,5 @@
  *
  * VBox frontends: VRDE (headless Remote Desktop server):
- * Header file with registration call for ffmpeg framebuffer
+ * Header file with registration call for VideoRec framebuffer
  */
 
@@ -31,5 +31,5 @@
 
 /**
- * Callback function to register an ffmpeg framebuffer.
+ * Callback function to register an VideoRec framebuffer.
  *
  * @returns COM status code.
@@ -41,9 +41,9 @@
  * @retval  retVal       The new framebuffer
  */
-typedef DECLCALLBACK(HRESULT) FNREGISTERFFMPEGFB(ULONG width,
+typedef DECLCALLBACK(HRESULT) FNREGISTERVIDEORECFB(ULONG width,
                                      ULONG height, ULONG bitrate,
                                      com::Bstr filename,
                                      IFramebuffer **retVal);
-typedef FNREGISTERFFMPEGFB *PFNREGISTERFFMPEGFB;
+typedef FNREGISTERVIDEORECFB *PFNREGISTERVIDEORECFB;
 
 #endif // __H_VBOXHEADLESS
Index: /trunk/src/VBox/Frontends/VBoxHeadless/VideoCapture/Makefile.kmk
===================================================================
--- /trunk/src/VBox/Frontends/VBoxHeadless/VideoCapture/Makefile.kmk	(revision 42466)
+++ /trunk/src/VBox/Frontends/VBoxHeadless/VideoCapture/Makefile.kmk	(revision 42467)
@@ -19,28 +19,29 @@
 include $(KBUILD_PATH)/subheader.kmk
 
-DLLS += VBoxFFmpegFB
-VBoxFFmpegFB_TEMPLATE     = VBOXMAINCLIENTDLL
+DLLS += VBoxVideoRecFB
+VBoxVideoRecFB_TEMPLATE     = VBOXMAINCLIENTDLL
 
 ifdef VBOX_WITH_VPX
-  VBoxFFmpegFB_DEFS      += \
+  VBoxVideoRecFB_DEFS      += \
     VBOX_WITH_VPX  
 endif
 
 ifdef VBOX_WITH_VPX
-  VBoxFFmpegFB_SDKS       = VBOX_FFMPEG VBOX_LIBPNG VBOX_ZLIB VBOX_VPX
+  VBoxVideoRecFB_SDKS       = VBOX_FFMPEG VBOX_LIBPNG VBOX_ZLIB VBOX_VPX
 else
-  VBoxFFmpegFB_SDKS       = VBOX_FFMPEG VBOX_LIBPNG VBOX_ZLIB 
+  VBoxVideoRecFB_SDKS       = VBOX_FFMPEG VBOX_LIBPNG VBOX_ZLIB 
 endif
 
 ifdef VBOX_WITH_VPX
-  VBoxFFmpegFB_SOURCES   +=  \
-    FFmpegFB.cpp \
-	EbmlWriter.cpp
+  VBoxVideoRecFB_SOURCES   +=  \
+    VideoRecFB.cpp \
+    EbmlWriter.cpp \
+    EncodeAndWrite.cpp
 else
-  VBoxFFmpegFB_SOURCES   +=  \
-    FFmpegFB.cpp 
+  VBoxVideoRecFB_SOURCES   +=  \
+    VideoRecFB.cpp 
 endif
 
-VBoxFFmpegFB_CXXFLAGS.linux += -fPIC
+VBoxVideoRecFB_CXXFLAGS.linux += -fPIC
 
 include $(FILE_KBUILD_SUB_FOOTER)

Index: /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.cpp	(revision 42466)
+++ /trunk/src/VBox/Frontends/VBoxHeadless/VBoxHeadless.cpp	(revision 42467)
@@ -486,5 +486,5 @@
 #ifdef VBOX_WITH_VIDEO_REC
 /**
  * Parse the environment for variables which can influence the FFMPEG settings.
  * purely for backwards compatibility.
  * @param pulFrameWidth may be updated with a desired frame width
@@ -613,5 +613,5 @@
     unsigned fCSAM  = ~0U;
 #ifdef VBOX_WITH_VIDEO_REC
-    unsigned fFFMPEG = 0;
+    unsigned fVIDEOREC = 0;
     unsigned long ulFrameWidth = 800;
     unsigned long ulFrameHeight = 600;
@@ -755,5 +755,5 @@
 #ifdef VBOX_WITH_VIDEO_REC
             case 'c':
-                fFFMPEG = true;
+                fVIDEOREC = true;
                 break;
             case 'w':
@@ -931,8 +931,8 @@
 #ifdef VBOX_WITH_VIDEO_REC
         IFramebuffer *pFramebuffer = 0;
-        RTLDRMOD hLdrFFmpegFB;
-        PFNREGISTERFFMPEGFB pfnRegisterFFmpegFB;
-
-        if (fFFMPEG)
+        RTLDRMOD hLdrVideoRecFB;
+        PFNREGISTERVIDEORECFB pfnRegisterVideoRecFB;
+
+        if (fVIDEOREC)
         {
             HRESULT         rcc = S_OK;
@@ -940,13 +940,13 @@
             RTERRINFOSTATIC ErrInfo;
 
-            Log2(("VBoxHeadless: loading VBoxFFmpegFB and libvpx shared library\n"));
+            Log2(("VBoxHeadless: loading VBoxVideoRecFB and libvpx shared library\n"));
             RTErrInfoInitStatic(&ErrInfo);
-            rrc = SUPR3HardenedLdrLoadAppPriv("VBoxFFmpegFB", &hLdrFFmpegFB, RTLDRLOAD_FLAGS_LOCAL, &ErrInfo.Core);
+            rrc = SUPR3HardenedLdrLoadAppPriv("VBoxVideoRecFB", &hLdrVideoRecFB, RTLDRLOAD_FLAGS_LOCAL, &ErrInfo.Core);
 
             if (RT_SUCCESS(rrc))
             {
-                Log2(("VBoxHeadless: looking up symbol VBoxRegisterFFmpegFB\n"));
-                rrc = RTLdrGetSymbol(hLdrFFmpegFB, "VBoxRegisterFFmpegFB",
-                                     reinterpret_cast<void **>(&pfnRegisterFFmpegFB));
+                Log2(("VBoxHeadless: looking up symbol VBoxRegisterVideoRecFB\n"));
+                rrc = RTLdrGetSymbol(hLdrVideoRecFB, "VBoxRegisterVideoRecFB",
+                                     reinterpret_cast<void **>(&pfnRegisterVideoRecFB));
                 if (RT_FAILURE(rrc))
                     LogError("Failed to load the video capture extension, possibly due to a damaged file\n", rrc);
@@ -956,6 +956,6 @@
             if (RT_SUCCESS(rrc))
             {
-                Log2(("VBoxHeadless: calling pfnRegisterFFmpegFB\n"));
-                rcc = pfnRegisterFFmpegFB(ulFrameWidth, ulFrameHeight, ulBitRate,
+                Log2(("VBoxHeadless: calling pfnRegisterVideoRecFB\n"));
+                rcc = pfnRegisterVideoRecFB(ulFrameWidth, ulFrameHeight, ulBitRate,
                                          pszMPEGFile, &pFramebuffer);
                 if (rcc != S_OK)
@@ -984,5 +984,5 @@
         {
 # ifdef VBOX_WITH_VIDEO_REC
-            if (fFFMPEG && uScreenId == 0)
+            if (fVIDEOREC && uScreenId == 0)
             {
                 /* Already registered. */
@@ -486,5 +486,5 @@
 #ifdef VBOX_WITH_VIDEO_REC
 /**
- * Parse the environment for variables which can influence the FFMPEG settings.
+ * Parse the environment for variables which can influence the VIDEOREC settings.
  * purely for backwards compatibility.
  * @param pulFrameWidth may be updated with a desired frame width